@@ -3,7 +3,7 @@ use Carp ();
 
 package Config::INI::Tiny;
 
-our $VERSION = '0.103';
+our $VERSION = '0.104';
 
 sub new { my $class = shift; bless { section0 => '', line0 => 0, pairs => 0, @_ }, $class }
 
@@ -17,7 +17,7 @@ sub parse {
 	my $n = $self->{'line0'}, my @out = my $s = [ $self->{'section0'} ], pos( $_[0] ) = 0;
 	BEGIN { utf8->import if eval { require utf8 } } # 5.6 compat
 	while ( ++$n, $_[0] =~ /$rx/g ) {
-		; defined $2 ? push @$s, $self->{'pairs'} ? [ "$2", "$3" ] : "$2", "$3"
+		; defined $2 ? push @$s, $self->{'pairs'} ? [ "$2", "$3" ] : ( "$2", "$3" )
 		: defined $1 ? push @out, $s = [ "$1" ]
 		: defined $4 ? Carp::croak map { s/"/\\"/g; qq'Bad INI syntax at line $n: "$_"' } "$4"
 		: ()
@@ -295,7 +295,7 @@ Aristotle Pagaltzis <pagaltzis@gmx.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Aristotle Pagaltzis.
+This software is copyright (c) 2021 by Aristotle Pagaltzis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
